==> phoenix_widgets-1.16.5.tar.gz: example/lib/phoenix_webview_main_page.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets_example/phoenix_webview_page.dart';

class PhoenixWebviewMainPage extends StatefulWidget {
  const PhoenixWebviewMainPage({Key? key}) : super(key: key);

  @override
  _PhoenixWebviewMainPageState createState() => _PhoenixWebviewMainPageState();
}

class _PhoenixWebviewMainPageState extends State<PhoenixWebviewMainPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix Webview Sample'),
      ),
      body: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16),
          child: Column(children: [
            ElevatedButton(
              onPressed: () async {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (context) => const PhoenixWebviewPage(
                      url: "https://flutter.dev/",
                    ),
                  ),
                );
              },
              child: const SizedBox(
                width: double.maxFinite,
                child: Center(child: Text("Normal Webiew")),
              ),
            ),
            ElevatedButton(
              onPressed: () async {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (context) => const PhoenixWebviewPage(
                      url:
                          "https://wa.me/60123456789?text=Test+Flutter+Webview",
                      specialString: [
                        'api.whatsapp',
                        'wa.me',
                        'whatsapp://send'
                      ],
                    ),
                  ),
                );
              },
              child: const SizedBox(
                width: double.maxFinite,
                child: Center(child: Text("Whatsapp Webiew")),
              ),
            ),
          ]),
        ),
      ),
    );
  }
}

==> phoenix_widgets-1.17.4.tar.gz: example/lib/phoenix_webview_main_page.dart <==
import 'package:flutter/material.dart';
import 'package:phoenix_widgets_example/phoenix_webview_page.dart';

class PhoenixWebviewMainPage extends StatefulWidget {
  const PhoenixWebviewMainPage({Key? key}) : super(key: key);

  @override
  State<PhoenixWebviewMainPage> createState() => _PhoenixWebviewMainPageState();
}

class _PhoenixWebviewMainPageState extends State<PhoenixWebviewMainPage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        title: const Text('Phoenix Webview Sample'),
      ),
      body: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16),
          child: Column(children: [
            ElevatedButton(
              onPressed: () async {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (context) => const PhoenixWebviewPage(
                      url: "https://flutter.dev/",
                    ),
                  ),
                );
              },
              child: const SizedBox(
                width: double.maxFinite,
                child: Center(child: Text("Normal Webiew")),
              ),
            ),
            ElevatedButton(
              onPressed: () async {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (context) => const PhoenixWebviewPage(
                      url:
                          "https://wa.me/60123456789?text=Test+Flutter+Webview",
                      specialString: [
                        'api.whatsapp',
                        'wa.me',
                        'whatsapp://send'
                      ],
                    ),
                  ),
                );
              },
              child: const SizedBox(
                width: double.maxFinite,
                child: Center(child: Text("Whatsapp Webiew")),
              ),
            ),
          ]),
        ),
      ),
    );
  }
}
